abundance generation
get_abundance_df(
weights,
weights_factor,
randomization_number,
abundance_file,
regenerate_abundance_df,
aggregation_factor_name,
seed
)the dataframe of weights, one row correspond to a series of observation
the dataframe which contains the different factor linked to the weights
the number of random abundance matrix to generate
the path and name of the RDS file to load/save the dataframe which contains the observed data and the generated matrix
boolean to specify if the abundance dataframe is computed again
vector of factor name for the generation of random matrix
the seed of the pseudo random number generator