weighted moments generation
get_weighted_mnts(
weights_factor,
trait_data,
weighted_moments_file,
regenerate_weighted_moments_df,
abundance_df,
randomization_number,
slope_distance,
intercept_distance,
factor_names = NULL
)the dataframe which contains the different factor linked to the weights
a vector of the data linked to the different factor
the path and name of the RDS file to load/save the dataframe which contains the calculated moments
boolean to specify if the weighted moments dataframe is computed again
the number of random abundance matrix to generate
slope of the theoretical distribution law (default: slope = 1 intercept = 1.86 skew-uniform distribution family)
intercept of the theoretical distribution law (default: slope = 1 intercept = 1.86 skew-uniform distribution family)